@@ -178,11 +178,6 @@ tp_stream_engine_stream_dispose (GObject *object)
   TpStreamEngineStream *stream = TP_STREAM_ENGINE_STREAM (object);
   TpStreamEngineStreamPrivate *priv = STREAM_PRIVATE (stream);
 
-#ifdef MAEMO_OSSO_SUPPORT
-  if (priv->media_server_proxy)
-    media_server_proxy_cleanup (stream);
-#endif
-
   if (priv->channel_path)
     {
       g_free (priv->channel_path);
@@ -242,6 +237,12 @@ tp_stream_engine_stream_dispose (GObject *object)
       priv->fs_stream = NULL;
     }
 
+
+#ifdef MAEMO_OSSO_SUPPORT
+  if (priv->media_server_proxy)
+    media_server_proxy_cleanup (stream);
+#endif
+
   if (priv->output_window_id)
     {
       gboolean ret;
@@ -1211,6 +1212,13 @@ tp_stream_engine_stream_go (
   priv->fs_stream = farsight_session_create_stream (
     fs_session, media_type, direction);
 
+  if (g_object_has_property (G_OBJECT (priv->fs_stream), "transmitter"))
+    {
+      g_object_set (G_OBJECT (priv->fs_stream),
+          "transmitter", "libjingle",
+          NULL);
+    }
+
   if (media_type == FARSIGHT_MEDIA_TYPE_VIDEO)
     {
       /* tell the Farsight stream to use the stream engine pipeline */
@@ -1507,7 +1515,8 @@ tp_stream_engine_stream_set_output_window (
     {
       DEBUG (stream, "using xvimagesink");
       sink = gst_element_factory_make ("xvimagesink", NULL);
-      g_object_set (sink, "sync", FALSE, NULL);
+      g_object_set (G_OBJECT (sink), "sync", FALSE, NULL);
+      g_object_set (G_OBJECT (sink), "qos", FALSE, NULL);
     }
 
   tp_stream_engine_add_output_window (engine, stream, sink, window_id);
