@@ -305,6 +305,7 @@ _add_preview_window (TpStreamEngine *obj, guint window_id, GError **error)
       g_debug ("using xvimagesink");
       sink = gst_element_factory_make ("xvimagesink", NULL);
       g_object_set (G_OBJECT (sink), "sync", FALSE, NULL);
+      g_object_set (G_OBJECT (sink), "qos", FALSE, NULL);
     }
 
   wp->created = TRUE;
@@ -319,7 +320,7 @@ _add_preview_window (TpStreamEngine *obj, guint window_id, GError **error)
       goto bin_add_failure;
     }
 
-  g_debug ("trying to set sink to PLAYING");
+  g_debug ("trying to set sink to PAUSED");
   state_change_ret = gst_element_set_state (sink, GST_STATE_PLAYING);
 
   if (state_change_ret != GST_STATE_CHANGE_SUCCESS &&
